/*
 * Zorin Menu: The official applications menu for Zorin OS.
 *
 * Copyright (C) 2016-2019 Zorin OS Technologies Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Credits:
 * This file is based on code from the quitfromdash extension by
 * Alex Palaistras
 */

const AppDisplay = imports.ui.appDisplay;
const Lang = imports.lang;
const Gio = imports.gi.Gio;
const GLib = imports.gi.GLib;
const Util = imports.misc.util;
const Me = imports.misc.extensionUtils.getCurrentExtension();
const Gettext = imports.gettext.domain(Me.metadata['gettext-domain']);
const _ = Gettext.gettext;
const Desktop = Me.imports.desktop;

var AppItemMenu = new Lang.Class({
    Name: 'AppItemMenu',
    Extends: AppDisplay.AppIconMenu,

    _init: function(source) {
        this.parent(source);
    },

    _redisplay: function() {
        this.parent();
        let app = this._source.app;
        if (!app)
            return;

        let desktop = GLib.get_user_special_dir(GLib.UserDirectory.DIRECTORY_DESKTOP);
        let file = Gio.File.new_for_path(GLib.build_filenamev([desktop, app.get_id()]));
        if (!file.query_exists(null)){
            this._appendSeparator();
            this._addToDesktopItem = this._appendMenuItem(_("Add to Desktop"));
            this._addToDesktopItem.connect('activate', Lang.bind(this, function() {
                Desktop.addToDesktop(app);
            }));
        }
    }
});
